@@ -515,40 +515,35 @@ class Query:
                                 formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
                         else:
                             # else
-                            formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
+                            if formatted_value is not None and where_condition.direction is None:
+                                formatted_cond = field_with_agg + " " + operator + " " + str(formatted_value)
+                            elif formatted_value is None and where_condition.direction is not None:
+                                if isinstance(where_condition.direction, PeriodOperator):
+                                    direction = where_condition.direction.name
+                                else:
+                                    direction = where_condition.direction
+
+                                if where_condition.steps is not None and where_condition.interval is not None:
+                                    formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
+                                elif where_condition.steps is not None and where_condition.interval is None:
+                                    formatted_cond = (
+                                            field_with_agg + " " + operator + " " + direction + " " + where_condition.steps
+                                    )
+                                elif where_condition.steps is None and where_condition.interval is not None:
+                                    formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction
+                                else:
+                                    formatted_cond = field_with_agg + " " + operator + " " + direction
+                            elif where_condition.field.complexExpression is not None:
+                                if where_condition.field.alias is not None:
+                                    formatted_cond = where_condition.field.complexExpression + " AS " + where_condition.field.alias
+                                else:
+                                    formatted_cond = where_condition.field.complexExpression
+                            elif operator is not None:
+                                formatted_cond = field_with_agg + " " + operator
+                            else:
+                                formatted_cond = field_with_agg
 
                         conditions.append(formatted_cond)
-                    else:
-                        if formatted_value is not None and where_condition.direction is None:
-                            formatted_cond = field_with_agg + " " + operator + " " + str(formatted_value)
-                        elif formatted_value is None and where_condition.direction is not None:
-                            if isinstance(where_condition.direction, PeriodOperator):
-                                direction = where_condition.direction.name
-                            else:
-                                direction = where_condition.direction
-
-                            if where_condition.steps is not None and where_condition.interval is not None:
-                                formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
-                            elif where_condition.steps is not None and where_condition.interval is None:
-                                formatted_cond = (
-                                        field_with_agg + " " + operator + " " + direction + " " + where_condition.steps
-                                )
-                            elif where_condition.steps is None and where_condition.interval is not None:
-                                formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction
-                            else:
-                                formatted_cond = field_with_agg + " " + operator + " " + direction
-
-                        elif operator is not None:
-                            formatted_cond = field_with_agg + " " + operator
-                        else:
-                            formatted_cond = field_with_agg
-                        conditions.append(formatted_cond)
-                elif where_condition.field.complexExpression is not None:
-                    if where_condition.field.alias is not None:
-                        formatted_cond = where_condition.field.complexExpression + " AS " + where_condition.field.alias
-                    else:
-                        formatted_cond = where_condition.field.complexExpression
-                    conditions.append(formatted_cond)
             elif isinstance(where_condition, CompositeCondition):
                 other_conds = self._where_spell_out(where_condition.conditions)
                 if where_condition.operator.name == "AND":
