@@ -34,13 +34,15 @@ if __name__ == '__main__':
     # print(str(dump) == decompressed_json)
 
     # TEST SPELL OUT
-    # smartquerty spellout
-    # sq = SmartQuery(queries=[Query(
-    #     fields=[Field(column="ADDRESS", alias="Address", internalDataType="STRING", sourceDataType="CLOB"),
-    #             Field(column="RENOVATION_DATE", alias="renovation_date", internalDataType="DATE", sourceDataType="TIME")],
-    #     orderBy=[Sorting(field="ADDRESS", order=SQLSorting.DESC),
-    #              Sorting(field="RENOVATION_DATE", order=SQLSorting.DESC)],
-    #     limit=8,
-    #     offset=0
-    # )])
-    # print(sq.spell_out())
+    # smartquery spell_out
+    sq = SmartQuery(queries=[Query(
+        fields=[Field(column="store_city", alias="Store City", internalDataType="STRING", sourceDataType="CLOB"),
+                Field(column="time_the_date", alias="Time", internalDataType="DATE", sourceDataType="TIME")],
+        where=[Condition(Field(column="time_the_date", alias="Time", internalDataType="DATE", sourceDataType="TIME"),
+                         operator="FROM", direction="NEXT", steps="2", interval="time_quarter")],
+        orderBy=[Sorting(field="Store City", order=SQLSorting.DESC),
+                 Sorting(field="Time", order=SQLSorting.DESC)],
+        limit=8,
+        offset=0
+    )])
+    print(sq.spell_out())
